summaryrefslogtreecommitdiffstats
path: root/src/hardware.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-04-15 17:53:42 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-04-15 17:53:42 -0500
commit3c32b869c2208758c2027d094c8930592370858a (patch)
tree39724674d33faf4a09f28fce507c7ccbbf79a9a3 /src/hardware.h
parent3ec8230e9f10645de684b5e03471e293481183d7 (diff)
downloadtdepowersave-3c32b869c2208758c2027d094c8930592370858a.tar.gz
tdepowersave-3c32b869c2208758c2027d094c8930592370858a.zip
Rename dbusHAL class to something more sensible
Diffstat (limited to 'src/hardware.h')
-rw-r--r--src/hardware.h9
1 files changed, 3 insertions, 6 deletions
diff --git a/src/hardware.h b/src/hardware.h
index f902499..3dd048b 100644
--- a/src/hardware.h
+++ b/src/hardware.h
@@ -48,10 +48,7 @@
// TDE hardware library
#include <tdehardwaredevices.h>
-// HAL Library
-#include <hal/libhal.h>
-
-#include "dbusHAL.h"
+#include "dbusInterface.h"
#include "hardware_battery.h"
#include "hardware_batteryCollection.h"
@@ -130,8 +127,8 @@ class HardwareInfo : public TQObject{
private:
TDEHardwareDevices *m_hwdevices;
- //! pointer to the dbusHAL connection class
- dbusHAL *dbus_HAL;
+ //! pointer to the dbusInterface connection class
+ dbusInterface *dbus_HAL;
//! hold udis of special hardware execpt batteries represented by a TQString pairs (name,udi)
/*!